# AgentConnectorLocalBindError

An error encounted when binding to the provided address. Errors may be system-dependent. They are provided for informational and diagnotic purposes. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**error_message** | **str** | The contents of the error | 
**error_time** | **datetime** | When the error occured | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


